unit globalroutines;

{$mode objfpc}{$H+}

interface

uses  SysUtils, IniFiles, Forms, Graphics, Dialogs,
  Classes, StdCtrls, Interfaces;

{ **************************************************************************** }
{ * GLOBALE DEFINES                                                          * }
{ *****************************************************************************}

{  .$define DEMO}

{ **************************************************************************** }
{ * GLOBALE TYPEN-Deklarationen                                              * }
{ *****************************************************************************}

// type

  //string8 = string[8];
  //ShortString = string;
  //PShortString = pstring;
  //EMyException = class(Exception);






    // PathSep, PathSeparator: path separator when adding many paths together (';', ...)
    // PathDelim, DirectorySeparator: directory separator for each platform ('/', '\', ...)
    // LineEnding: proper line ending character sequence (#13#10 - CRLF, #10 - LF, ...)
    // https://wiki.freepascal.org/Multiplatform_Programming_Guide


{ **************************************************************************** }
{ * GLOBALE VARIABLEN Deklarationen                                          * }
{ *****************************************************************************}
// var FirebirdDatabase: string;

{ **************************************************************************** }
{ * GLOBALE PROEDURE und FUNCTION                                            * }
{ *****************************************************************************}

{ Glonale Parameter gültig für alle Programme }
procedure SetGlobalParameters;

{ Vereinfachtes lesen von INI-Daten }
function GlobIniRead(var GlobIniSection, GlobIniKey: string): string;
function LemIniRead(var LemIniFile, LemIniSection, LemIniKey: string): string;
function ConstIniRead(var ConstIniSection: string; const LemIniKey: string): string;

{ Vereinfachtes Schreiben von INI-Dateien }
function GlobIniWrite(var GlobIniSection, GlobIniKey, GlobIniValue: string): string;
function LemIniWrite(var LemIniFile, LemIniSection, LemIniKey, LemIniValue: string): string;
function ConstIniWrite(var ConstIniSection: string; const ConstIniKey:string; var ConstIniValue: string): string;

{ Den Pfad der Anwendung ohne Anwendung korrekt zurückgeben }
procedure GetApplicationPath(var ap: string);


{ **************************************************************************** }
{ * GLOBALE CONST-Deklarationen                                              * }
{ *****************************************************************************}






implementation

{ **************************************************************************** }
{ * SETGLOBALPARAMETERS wird beim Pogrammstart einmal aufgerufen um alle für * }
{ * das Programm benötigten Einstellungen und Globale Variablen zu initieren * }
{ **************************************************************************** }
procedure SetGlobalParameters;
begin
  // https://lazarus-ccr.sourceforge.io/docs/lcl/forms/tapplication.html
  // https://wiki.freepascal.org/Command_line_parameters_and_environment_variables
  // Wert für DBProtocol setzen
  // DBProtocol := 'firebird';
end;




{ **************************************************************************** }
{ * GetApplicationPath                                                       * }
{ **************************************************************************** }
procedure GetApplicationPath(var ap: string);
var s: string;
begin
   s:= ExtractFilePath(Application.ExeName);
   if (RightStr(s,1)<>PathDelim) then s:= s+ PathDelim;
   ap:= s;
end;


{ **************************************************************************** }
{ * LEMINIREAD vereinfachtes lesen von INI-Daten                             * }
{ **************************************************************************** }
function LemIniRead(var LemIniFile, LemIniSection, LemIniKey: string): string;

var
  List: TiniFile;
  LemVal: string;
  le: integer;

begin
  List := TIniFile.Create(LemIniFile + '.ini');
  LemVal := List.ReadString(LeminiSection, LemIniKey, '');
  List.Free;
  le := Length(LemVal) - 2;
  LemVal := Copy(LemVal, 2, le);
  LemIniRead := LemVal;
end;

{ **************************************************************************** }
{ * GLOBINIREAD vereinfachtes lesen von INI-Daten ohne Dateinamenparameter   * }
{ **************************************************************************** }
function GlobIniRead(var GlobIniSection, GlobIniKey: string): string;

var
  s: string;

begin
  s := Application.Title;
  GlobIniRead := LemIniRead(s, GlobIniSection, GlobIniKey);
end;

{ **************************************************************************** }
{ * GLOBINIREAD vereinfachtes lesen von INI-Daten ohne Dateinamenparameter   * }
{ **************************************************************************** }
function ConstIniRead(var ConstIniSection: string; const LemIniKey: string): string;

var
  s, IniKey: string;

begin
  s := Application.Title;
  IniKey:= LemIniKey;
  ConstIniRead := LemIniRead(s, ConstIniSection, IniKey);
end;




{ **************************************************************************** }
{ * LEMINIWRITE vereinfachtes schreiben von INI-Daten                        * }
{ **************************************************************************** }
function LemIniWrite(var LemIniFile, LemIniSection, LemIniKey, LemIniValue:
  string): string;

var
  List: TiniFile;
  LemVal: string;
begin
  LemVal := '"' + LemIniValue + '"';
  List := TIniFile.Create(LemIniFile + '.ini');
  List.WriteString(LemIniSection, LemIniKey, LemVal);
  List.Free;
  LemIniWrite := LemIniValue;
end;

{ **************************************************************************** }
{ * GLOBINIWRITE vereinfachtes lesen von INI-Daten ohne Dateinamenparameter   * }
{ **************************************************************************** }
function GlobIniWrite(var GlobIniSection, GlobIniKey, GlobIniValue: string): string;

var s: string;

begin
  s := Application.Title;
  LemIniWrite(s, GlobIniSection, GlobIniKey, GlobIniValue);
  GlobIniWrite := GlobIniValue;
end;


{ **************************************************************************** }
{ * CONSTINIWRITE vereinfachtes lesen von INI-Daten ohne Dateinamenparameter  * }
{ **************************************************************************** }
function ConstIniWrite(var ConstIniSection: string; const ConstIniKey:string; var ConstIniValue: string): string;

var s, IniKey: string;

begin
  s := Application.Title;
  IniKey:= ConstIniKey;
  LemIniWrite(s, ConstIniSection, IniKey, ConstIniValue);
  ConstIniWrite := ConstIniValue;
end;





{ **************************************************************************** }
{ *                             INITIALIZATION                               * }
{ **************************************************************************** }
initialization
  { die globalen Einstellungen aufrufen }
  // SetGlobalParameters;



end.
